@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -64,7 +64,8 @@ class IndexEndpointServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = IndexEndpointServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[IndexEndpointServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -170,10 +171,16 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def index_path(project: str, location: str, index: str,) -> str:
+    def index_path(
+        project: str,
+        location: str,
+        index: str,
+    ) -> str:
         """Returns a fully-qualified index string."""
         return "projects/{project}/locations/{location}/indexes/{index}".format(
-            project=project, location=location, index=index,
+            project=project,
+            location=location,
+            index=index,
         )
 
     @staticmethod
@@ -186,10 +193,16 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def index_endpoint_path(project: str, location: str, index_endpoint: str,) -> str:
+    def index_endpoint_path(
+        project: str,
+        location: str,
+        index_endpoint: str,
+    ) -> str:
         """Returns a fully-qualified index_endpoint string."""
         return "projects/{project}/locations/{location}/indexEndpoints/{index_endpoint}".format(
-            project=project, location=location, index_endpoint=index_endpoint,
+            project=project,
+            location=location,
+            index_endpoint=index_endpoint,
         )
 
     @staticmethod
@@ -202,7 +215,9 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -215,9 +230,13 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -226,9 +245,13 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -237,9 +260,13 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -248,10 +275,14 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -437,8 +468,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Creates an IndexEndpoint.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -532,7 +562,12 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -556,8 +591,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> index_endpoint.IndexEndpoint:
         r"""Gets an IndexEndpoint.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -633,7 +667,12 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -649,8 +688,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> pagers.ListIndexEndpointsPager:
         r"""Lists IndexEndpoints in a Location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -729,12 +767,20 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListIndexEndpointsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -752,8 +798,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> gca_index_endpoint.IndexEndpoint:
         r"""Updates an IndexEndpoint.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -842,7 +887,12 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -858,8 +908,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Deletes an IndexEndpoint.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -951,7 +1000,12 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -978,9 +1032,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         DeployedIndex within it.
         Only non-empty Indexes can be deployed.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1079,7 +1131,12 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -1106,9 +1163,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         DeployedIndex from it, and freeing all resources it's
         using.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1203,7 +1258,12 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -1229,9 +1289,7 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         r"""Update an existing DeployedIndex under an
         IndexEndpoint.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1332,7 +1390,12 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
